package com.ruoyi.controller;

import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.domain.Timesheet;
import com.ruoyi.domain.dto.AddTimesheetDTO;
import com.ruoyi.domain.dto.TimesheetDTO;
import com.ruoyi.service.ITimesheetService;
import org.springframework.format.annotation.DateTimeFormat;
import org.springframework.http.ResponseEntity;
import org.springframework.scheduling.annotation.Async;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 工时记录Controller
 *
 * @author ruoyi
 * @date 2025-03-11
 */
@RestController
@RequestMapping("/timesheet/timesheet")
public class TimesheetController extends BaseController
{
    @Autowired
    private ITimesheetService timesheetService;

    /*查询个人工时*/
    @PreAuthorize("@ss.hasPermi('timesheet:timesheet:list')")
    @GetMapping("/pTimesheetList")
    public ResponseEntity<List<TimesheetDTO>> getProjectTimesheetList(
            @ModelAttribute Timesheet timesheet,
            @RequestParam(required = false) @DateTimeFormat(pattern = "yyyy-MM-dd") Date startTime,
            @RequestParam(required = false) @DateTimeFormat(pattern = "yyyy-MM-dd") Date endTime,
            @RequestParam(required = false) String managerName // 添加 managerName 参数
    ) {
        // 设置查询条件
        timesheet.setStartTime(startTime);
        timesheet.setEndTime(endTime);
        timesheet.setManagerName(managerName); // 设置 managerName

        List<TimesheetDTO> result = timesheetService.getProjectTimesheetList(timesheet);
        return ResponseEntity.ok(result);
    }

    /*
    * 填报工时--查询个人填报
     */
    @PreAuthorize("@ss.hasPermi('timesheet:timesheet:list')")
    @GetMapping("/personalTimesheet/{employId}")
    public ResponseEntity<List<AddTimesheetDTO>> getPersonalTimesheet(@PathVariable("employId") Long employId) {
        List<AddTimesheetDTO> result = timesheetService.getPersonalTimesheet(employId);
        return ResponseEntity.ok(result);
    }

    /**
     * 批量插入工时记录
     *
     */
    @PreAuthorize("@ss.hasPermi('timesheet:timesheet:add')")
    @Log(title = "插入工时记录", businessType = BusinessType.INSERT)
    @PostMapping("/batchInsert")
    public AjaxResult batchInsertTimesheet(@RequestBody AddTimesheetDTO addTimesheetDTO) {
        logger.info("Received batch insert request: {}", addTimesheetDTO);
        int result = timesheetService.insertTimesheetList(addTimesheetDTO);
        return toAjax(result);
    }

    /**
     * 查询工时记录列表
     */
    @PreAuthorize("@ss.hasPermi('timesheet:timesheet:list')")
    @GetMapping("/list")
    public TableDataInfo list(Timesheet timesheet)
    {
        startPage();
        List<Timesheet> list = timesheetService.selectTimesheetList(timesheet);
        return getDataTable(list);
    }

    /**
     * 导出工时记录列表
     */
    @PreAuthorize("@ss.hasPermi('timesheet:timesheet:export')")
    @Log(title = "工时记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Timesheet timesheet)
    {
        List<Timesheet> list = timesheetService.selectTimesheetList(timesheet);
        ExcelUtil<Timesheet> util = new ExcelUtil<Timesheet>(Timesheet.class);
        util.exportExcel(response, list, "工时记录数据");
    }

    /**
     * 获取工时记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('timesheet:timesheet:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(timesheetService.selectTimesheetById(id));
    }

    /**
     * 新增工时记录
     */
    @PreAuthorize("@ss.hasPermi('timesheet:timesheet:add')")
    @Log(title = "工时记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Timesheet timesheet)
    {
        return toAjax(timesheetService.insertTimesheet(timesheet));
    }

    /**
     * 修改工时记录
     */
    @PreAuthorize("@ss.hasPermi('timesheet:timesheet:edit')")
    @Log(title = "工时记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Timesheet timesheet)
    {
        return toAjax(timesheetService.updateTimesheet(timesheet));
    }

    /**
     * 删除工时记录
     */
    @PreAuthorize("@ss.hasPermi('timesheet:timesheet:remove')")
    @Log(title = "工时记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(timesheetService.deleteTimesheetByIds(ids));
    }
}
